pub struct PushSourcePuppet { /* private fields */ }Expand description
A PushSource that allows a single client and can be controlled by a test.
Implementations
Sourceimpl PushSourcePuppet
impl PushSourcePuppet
Sourcepub async fn set_sample(&self, sample: TimeSample)
pub async fn set_sample(&self, sample: TimeSample)
Set the next sample reported by the time source.
Sourcepub async fn set_status(&self, status: Status)
pub async fn set_status(&self, status: Status)
Set the next status reported by the time source.
Sourcepub fn simulate_crash(&self)
pub fn simulate_crash(&self)
Simulate a crash by closing client channels and wiping state.
Sourcepub fn lifetime_served_connections(&self) -> u32
pub fn lifetime_served_connections(&self) -> u32
Returns the number of cumulative connections served. This allows asserting behavior such as whether Timekeeper has restarted a connection.