pub struct RemotePushSourcePuppet { /* private fields */ }Implementations
Sourceimpl RemotePushSourcePuppet
impl RemotePushSourcePuppet
Sourcepub fn new(proxy: PushSourcePuppetProxy) -> Arc<Self>
pub fn new(proxy: PushSourcePuppetProxy) -> Arc<Self>
Creates a new RemotePushSourcePuppet.
Sourcepub async fn set_sample(&self, sample: TimeSample)
pub async fn set_sample(&self, sample: TimeSample)
Set the next sample reported by the time source.
Sourcepub async fn set_status(&self, status: Status)
pub async fn set_status(&self, status: Status)
Set the next status reported by the time source.
Sourcepub async fn simulate_crash(&self)
pub async fn simulate_crash(&self)
Simulate a crash by closing client channels and wiping state.
Sourcepub async fn lifetime_served_connections(&self) -> u32
pub async fn lifetime_served_connections(&self) -> u32
Returns the number of cumulative connections served. This allows asserting behavior such as whether Timekeeper has restarted a connection.